package com.hungraim.ltc.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.hungraim.ltc.pojo.vo.assessment.ReTaskDistributionVO;
import com.hungraim.ltc.service.ReTaskService;
import com.hungraim.ltc.util.Result;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

/**
 * 复评Controller
 *
 * @author czz
 */
@RestController
@RequestMapping("/api.assessment/reTask")
@Slf4j
public class ReTaskController {

    @Autowired
    private ReTaskService reTaskService;

    /**
     * 复评申请列表
     *
     * @param organId        适用机构id
     * @param isIncluded     是否包含下级机构,值为true，则包含organId的下层机构
     * @param acptProvincial 所在省
     * @param acptCity       所在市
     * @param acptCrea       所在区域
     * @param realName       失能人员姓名
     * @param certiCode      失能人员身份证号码
     * @param dataFrom       申请来源
     * @param srvOrganId     护理机构
     * @param applyMethod    申请类别
     * @param pageNum        当前页
     * @param pageSize       每页几条数据
     */
    @RequestMapping("/reTaskDistributionList")
    public Result<Page<ReTaskDistributionVO>> reTaskDistributionList(@RequestParam(defaultValue = "1") Integer pageNum, @RequestParam(defaultValue = "10") Integer pageSize,
                                                                     Long organId, Boolean isIncluded, String acptProvincial, String acptCity, String acptCrea,
                                                                     String realName, String certiCode, String dataFrom, String srvOrganId, String applyMethod) {
        Page<ReTaskDistributionVO> page = new Page<>(pageNum, pageSize);
        page = reTaskService.reTaskDistributionList(page, organId, isIncluded, acptProvincial, acptCity, acptCrea, realName, certiCode, dataFrom, srvOrganId, applyMethod);
        return Result.success(page);
    }

}
